//Задаем путь .xml-файлов задач
function [errTasks,..//Ошибки задач
          errMsgTasks,..//Сообщения об ошибках задач
          err,msg]=ExecuteTasksGen(tasksNames,..//Массив .sce файлов задач
                                   projectName,..//Имя проекта
                                   typeTask,..//Тип задачи
                                   errPrintMsg..//Необходимость печати сообщений об ошибках
                                   )
    //Проверяем и обрабатываем аргументы
    [nRez,nArg] = argn();//Число аргументов
    select nArg
    case 0 then
        error('The function ExecuteTasksGen takes 1, 2, 3 or 4 arguments');
    case 1 then
        projectName = "";//Имя проекта по умолчанию отсутcтвует
        typeTask = '';//По умолчанию - обычная задача
        errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
    case 2 then
        if type(projectName) == 4 then
            errPrintMsg = projectName;//Необходимость печати сообщений об ошибках
            projectName = "";//Имя проекта по умолчанию отсутcтвует
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
        end
        typeTask = '';//По умолчанию - обычная задача
    case 3 then
        if type(typeTask) == 4 then
            errPrintMsg = typeTask;//Необходимость печати сообщений об ошибках
            typeTask = '';//По умолчанию - обычная задача
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщение об ошибках
        end
    end
    
    //Формируем полные имена файлов задач
    [tasksSCEFilesPath,..//Путь к xml-файлам задач
     err,msg..//Код ошибки и сообщение ошибки
     ]=GetTaskPath(0, errPrintMsg);//Получаем путь к файлам задач
    if err ~= 0 then
        return;
    end
    tasksNames = basename(tasksNames) + '.sce';//Обрабатываем имена задач
    fullTasksNames = fullfile(tasksSCEFilesPath,projectName,typeTask,tasksNames);//Полные имена файлов задач
    
    //Запускаем задачи
    nTasks = size(fullTasksNames,'*');//Число задач
    if nRez > 0 then
        errTasks = zeros(fullTasksNames);//Ошибки задач
    end
    if (nRez > 1) || errPrintMsg then
        errMsgTasks = repmat('',[1,nTasks]);//Сообщения об ошибках
    end
    for ind=1:nTasks//Последовательно запускаем решение задач
        fullTasksName=fullTasksNames(ind);//Полное имя текущей задачи
        errclear();//Чистим сообщения об ошибках
        try
            exec(fullTasksName);//Запускаем задачу
        catch
            if nRez > 0 then
                errTasks(ind) = 1;//Вышла ошибка
            end
            if (nRez > 1) || errPrintMsg then
                errMsgTasks(ind) = lasterror();//Сообщение об ошибке
            end
            if errPrintMsg then
                disp(errMsgTasks(ind));
            end
        end
    end
    err = 0;//Ошибок нет
endfunction
